/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'nb', {
	border: 'Vis ramme rundt iframe',
	noUrl: 'Vennligst skriv inn URL for iframe',
	scrolling: 'Aktiver scrollefelt',
	title: 'Egenskaper for IFrame',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
